"""Contains all the data models used in inputs/outputs"""

from .cancel_job_body import CancelJobBody
from .cancel_process_body import CancelProcessBody
from .create_job_body import CreateJobBody
from .create_job_body_circuit import CreateJobBodyCircuit
from .create_process_body import CreateProcessBody
from .create_session_body import CreateSessionBody
from .create_session_body_booking_demand import CreateSessionBodyBookingDemand
from .list_applications_application_type import ListApplicationsApplicationType
from .list_applications_order_by import ListApplicationsOrderBy
from .list_bookings_order_by import ListBookingsOrderBy
from .list_job_results_order_by import ListJobResultsOrderBy
from .list_jobs_order_by import ListJobsOrderBy
from .list_platforms_order_by import ListPlatformsOrderBy
from .list_platforms_platform_technology import ListPlatformsPlatformTechnology
from .list_platforms_platform_type import ListPlatformsPlatformType
from .list_process_results_order_by import ListProcessResultsOrderBy
from .list_processes_order_by import ListProcessesOrderBy
from .list_sessions_order_by import ListSessionsOrderBy
from .scaleway_qaas_v1_alpha_1_application import ScalewayQaasV1Alpha1Application
from .scaleway_qaas_v1_alpha_1_application_type import (
    ScalewayQaasV1Alpha1ApplicationType,
)
from .scaleway_qaas_v1_alpha_1_booking import ScalewayQaasV1Alpha1Booking
from .scaleway_qaas_v1_alpha_1_booking_status import ScalewayQaasV1Alpha1BookingStatus
from .scaleway_qaas_v1_alpha_1_job import ScalewayQaasV1Alpha1Job
from .scaleway_qaas_v1_alpha_1_job_circuit import ScalewayQaasV1Alpha1JobCircuit
from .scaleway_qaas_v1_alpha_1_job_result import ScalewayQaasV1Alpha1JobResult
from .scaleway_qaas_v1_alpha_1_job_status import ScalewayQaasV1Alpha1JobStatus
from .scaleway_qaas_v1_alpha_1_list_applications_response import (
    ScalewayQaasV1Alpha1ListApplicationsResponse,
)
from .scaleway_qaas_v1_alpha_1_list_bookings_response import (
    ScalewayQaasV1Alpha1ListBookingsResponse,
)
from .scaleway_qaas_v1_alpha_1_list_job_results_response import (
    ScalewayQaasV1Alpha1ListJobResultsResponse,
)
from .scaleway_qaas_v1_alpha_1_list_jobs_response import (
    ScalewayQaasV1Alpha1ListJobsResponse,
)
from .scaleway_qaas_v1_alpha_1_list_platforms_response import (
    ScalewayQaasV1Alpha1ListPlatformsResponse,
)
from .scaleway_qaas_v1_alpha_1_list_process_results_response import (
    ScalewayQaasV1Alpha1ListProcessResultsResponse,
)
from .scaleway_qaas_v1_alpha_1_list_processes_response import (
    ScalewayQaasV1Alpha1ListProcessesResponse,
)
from .scaleway_qaas_v1_alpha_1_list_session_ac_ls_request_order_by import (
    ScalewayQaasV1Alpha1ListSessionACLsRequestOrderBy,
)
from .scaleway_qaas_v1_alpha_1_list_session_ac_ls_response import (
    ScalewayQaasV1Alpha1ListSessionACLsResponse,
)
from .scaleway_qaas_v1_alpha_1_list_sessions_response import (
    ScalewayQaasV1Alpha1ListSessionsResponse,
)
from .scaleway_qaas_v1_alpha_1_platform import ScalewayQaasV1Alpha1Platform
from .scaleway_qaas_v1_alpha_1_platform_availability import (
    ScalewayQaasV1Alpha1PlatformAvailability,
)
from .scaleway_qaas_v1_alpha_1_platform_booking_requirement import (
    ScalewayQaasV1Alpha1PlatformBookingRequirement,
)
from .scaleway_qaas_v1_alpha_1_platform_hardware import (
    ScalewayQaasV1Alpha1PlatformHardware,
)
from .scaleway_qaas_v1_alpha_1_platform_price_per_circuit import (
    ScalewayQaasV1Alpha1PlatformPricePerCircuit,
)
from .scaleway_qaas_v1_alpha_1_platform_price_per_hour import (
    ScalewayQaasV1Alpha1PlatformPricePerHour,
)
from .scaleway_qaas_v1_alpha_1_platform_price_per_shot import (
    ScalewayQaasV1Alpha1PlatformPricePerShot,
)
from .scaleway_qaas_v1_alpha_1_platform_technology import (
    ScalewayQaasV1Alpha1PlatformTechnology,
)
from .scaleway_qaas_v1_alpha_1_platform_type import ScalewayQaasV1Alpha1PlatformType
from .scaleway_qaas_v1_alpha_1_process import ScalewayQaasV1Alpha1Process
from .scaleway_qaas_v1_alpha_1_process_result import ScalewayQaasV1Alpha1ProcessResult
from .scaleway_qaas_v1_alpha_1_process_status import ScalewayQaasV1Alpha1ProcessStatus
from .scaleway_qaas_v1_alpha_1_session import ScalewayQaasV1Alpha1Session
from .scaleway_qaas_v1_alpha_1_session_access import ScalewayQaasV1Alpha1SessionAccess
from .scaleway_qaas_v1_alpha_1_session_origin_type import (
    ScalewayQaasV1Alpha1SessionOriginType,
)
from .scaleway_qaas_v1_alpha_1_session_status import ScalewayQaasV1Alpha1SessionStatus
from .terminate_session_body import TerminateSessionBody
from .update_booking_body import UpdateBookingBody
from .update_job_body import UpdateJobBody
from .update_process_body import UpdateProcessBody
from .update_session_body import UpdateSessionBody

__all__ = (
    "CancelJobBody",
    "CancelProcessBody",
    "CreateJobBody",
    "CreateJobBodyCircuit",
    "CreateProcessBody",
    "CreateSessionBody",
    "CreateSessionBodyBookingDemand",
    "ListApplicationsApplicationType",
    "ListApplicationsOrderBy",
    "ListBookingsOrderBy",
    "ListJobResultsOrderBy",
    "ListJobsOrderBy",
    "ListPlatformsOrderBy",
    "ListPlatformsPlatformTechnology",
    "ListPlatformsPlatformType",
    "ListProcessesOrderBy",
    "ListProcessResultsOrderBy",
    "ListSessionsOrderBy",
    "ScalewayQaasV1Alpha1Application",
    "ScalewayQaasV1Alpha1ApplicationType",
    "ScalewayQaasV1Alpha1Booking",
    "ScalewayQaasV1Alpha1BookingStatus",
    "ScalewayQaasV1Alpha1Job",
    "ScalewayQaasV1Alpha1JobCircuit",
    "ScalewayQaasV1Alpha1JobResult",
    "ScalewayQaasV1Alpha1JobStatus",
    "ScalewayQaasV1Alpha1ListApplicationsResponse",
    "ScalewayQaasV1Alpha1ListBookingsResponse",
    "ScalewayQaasV1Alpha1ListJobResultsResponse",
    "ScalewayQaasV1Alpha1ListJobsResponse",
    "ScalewayQaasV1Alpha1ListPlatformsResponse",
    "ScalewayQaasV1Alpha1ListProcessesResponse",
    "ScalewayQaasV1Alpha1ListProcessResultsResponse",
    "ScalewayQaasV1Alpha1ListSessionACLsRequestOrderBy",
    "ScalewayQaasV1Alpha1ListSessionACLsResponse",
    "ScalewayQaasV1Alpha1ListSessionsResponse",
    "ScalewayQaasV1Alpha1Platform",
    "ScalewayQaasV1Alpha1PlatformAvailability",
    "ScalewayQaasV1Alpha1PlatformBookingRequirement",
    "ScalewayQaasV1Alpha1PlatformHardware",
    "ScalewayQaasV1Alpha1PlatformPricePerCircuit",
    "ScalewayQaasV1Alpha1PlatformPricePerHour",
    "ScalewayQaasV1Alpha1PlatformPricePerShot",
    "ScalewayQaasV1Alpha1PlatformTechnology",
    "ScalewayQaasV1Alpha1PlatformType",
    "ScalewayQaasV1Alpha1Process",
    "ScalewayQaasV1Alpha1ProcessResult",
    "ScalewayQaasV1Alpha1ProcessStatus",
    "ScalewayQaasV1Alpha1Session",
    "ScalewayQaasV1Alpha1SessionAccess",
    "ScalewayQaasV1Alpha1SessionOriginType",
    "ScalewayQaasV1Alpha1SessionStatus",
    "TerminateSessionBody",
    "UpdateBookingBody",
    "UpdateJobBody",
    "UpdateProcessBody",
    "UpdateSessionBody",
)



from enum import Enum


class ScalewayQaasV1Alpha1SessionStatus(str, Enum):
    RUNNING = "running"
    STARTING = "starting"
    STOPPED = "stopped"
    STOPPING = "stopping"
    UNKNOWN_STATUS = "unknown_status"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="ScalewayQaasV1Alpha1PlatformBookingRequirement")


@_attrs_define
class ScalewayQaasV1Alpha1PlatformBookingRequirement:
    """Booking constraints to fit if the platform is bookable.

    Attributes:
        min_duration (Union[None, Unset, str]): Minimal duration of any booking based on this platform. (in seconds)
            Example: 2.5s.
        max_duration (Union[None, Unset, str]): Maximal duration of any bookings based on this platform. (in seconds)
            Example: 2.5s.
        max_cancellation_duration (Union[None, Unset, str]): Allowed time to cancel a booking attached to this platform
            before the beginning of the session. (in seconds) Example: 2.5s.
        max_planification_duration (Union[None, Unset, str]): Allowed planification time from now where the platform can
            be booked in the future. (in seconds) Example: 2.5s.
    """

    min_duration: Union[None, Unset, str] = UNSET
    max_duration: Union[None, Unset, str] = UNSET
    max_cancellation_duration: Union[None, Unset, str] = UNSET
    max_planification_duration: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        min_duration: Union[None, Unset, str]
        if isinstance(self.min_duration, Unset):
            min_duration = UNSET
        else:
            min_duration = self.min_duration

        max_duration: Union[None, Unset, str]
        if isinstance(self.max_duration, Unset):
            max_duration = UNSET
        else:
            max_duration = self.max_duration

        max_cancellation_duration: Union[None, Unset, str]
        if isinstance(self.max_cancellation_duration, Unset):
            max_cancellation_duration = UNSET
        else:
            max_cancellation_duration = self.max_cancellation_duration

        max_planification_duration: Union[None, Unset, str]
        if isinstance(self.max_planification_duration, Unset):
            max_planification_duration = UNSET
        else:
            max_planification_duration = self.max_planification_duration

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if min_duration is not UNSET:
            field_dict["min_duration"] = min_duration
        if max_duration is not UNSET:
            field_dict["max_duration"] = max_duration
        if max_cancellation_duration is not UNSET:
            field_dict["max_cancellation_duration"] = max_cancellation_duration
        if max_planification_duration is not UNSET:
            field_dict["max_planification_duration"] = max_planification_duration

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)

        def _parse_min_duration(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        min_duration = _parse_min_duration(d.pop("min_duration", UNSET))

        def _parse_max_duration(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        max_duration = _parse_max_duration(d.pop("max_duration", UNSET))

        def _parse_max_cancellation_duration(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        max_cancellation_duration = _parse_max_cancellation_duration(
            d.pop("max_cancellation_duration", UNSET)
        )

        def _parse_max_planification_duration(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        max_planification_duration = _parse_max_planification_duration(
            d.pop("max_planification_duration", UNSET)
        )

        scaleway_qaas_v1_alpha_1_platform_booking_requirement = cls(
            min_duration=min_duration,
            max_duration=max_duration,
            max_cancellation_duration=max_cancellation_duration,
            max_planification_duration=max_planification_duration,
        )

        scaleway_qaas_v1_alpha_1_platform_booking_requirement.additional_properties = d
        return scaleway_qaas_v1_alpha_1_platform_booking_requirement

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class ListSessionsOrderBy(str, Enum):
    CREATED_AT_ASC = "created_at_asc"
    CREATED_AT_DESC = "created_at_desc"
    NAME_ASC = "name_asc"
    NAME_DESC = "name_desc"
    STARTED_AT_ASC = "started_at_asc"
    STARTED_AT_DESC = "started_at_desc"
    STATUS_ASC = "status_asc"
    STATUS_DESC = "status_desc"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..models.scaleway_qaas_v1_alpha_1_session_origin_type import (
    ScalewayQaasV1Alpha1SessionOriginType,
)
from ..models.scaleway_qaas_v1_alpha_1_session_status import (
    ScalewayQaasV1Alpha1SessionStatus,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="ScalewayQaasV1Alpha1Session")


@_attrs_define
class ScalewayQaasV1Alpha1Session:
    """
    Attributes:
        id (Union[Unset, str]): Unique ID of the session.
        name (Union[Unset, str]): Name of the session.
        platform_id (Union[Unset, str]): Platform ID for which the session has been created.
        created_at (Union[None, Unset, datetime.datetime]): The time at which the session was created. (RFC 3339 format)
            Example: 2022-03-22T12:34:56.123456Z.
        started_at (Union[None, Unset, datetime.datetime]): The time at which the session started. (RFC 3339 format)
            Example: 2022-03-22T12:34:56.123456Z.
        updated_at (Union[None, Unset, datetime.datetime]): The time at which the session was updated. (RFC 3339 format)
            Example: 2022-03-22T12:34:56.123456Z.
        terminated_at (Union[None, Unset, datetime.datetime]): The time at which the session was terminated. (RFC 3339
            format) Example: 2022-03-22T12:34:56.123456Z.
        max_idle_duration (Union[None, Unset, str]): Maximum idle time before the session ends. (in seconds) Example:
            2.5s.
        max_duration (Union[None, Unset, str]): Maximum duration before the session ends. (in seconds) Example: 2.5s.
        waiting_job_count (Union[Unset, int]): Number of waiting jobs linked to the session.
        finished_job_count (Union[Unset, int]): Number of finished jobs linked to the session.
        status (Union[Unset, ScalewayQaasV1Alpha1SessionStatus]): Status of the session. Default:
            ScalewayQaasV1Alpha1SessionStatus.UNKNOWN_STATUS.
        project_id (Union[Unset, str]): Project ID in which the session has been created.
        tags (Union[None, Unset, list[str]]): Tags of the session.
        deduplication_id (Union[Unset, str]): Deduplication ID of the session.
        origin_type (Union[Unset, ScalewayQaasV1Alpha1SessionOriginType]): Resource type that creates the session.
            Default: ScalewayQaasV1Alpha1SessionOriginType.UNKNOWN_ORIGIN_TYPE.
        origin_id (Union[None, Unset, str]): Unique ID of the session's origin resource (if exists).
        progress_message (Union[None, Unset, str]): Any progress of the session.
        booking_id (Union[None, Unset, str]): An optional booking unique ID of an attached booking.
    """

    id: Union[Unset, str] = UNSET
    name: Union[Unset, str] = UNSET
    platform_id: Union[Unset, str] = UNSET
    created_at: Union[None, Unset, datetime.datetime] = UNSET
    started_at: Union[None, Unset, datetime.datetime] = UNSET
    updated_at: Union[None, Unset, datetime.datetime] = UNSET
    terminated_at: Union[None, Unset, datetime.datetime] = UNSET
    max_idle_duration: Union[None, Unset, str] = UNSET
    max_duration: Union[None, Unset, str] = UNSET
    waiting_job_count: Union[Unset, int] = UNSET
    finished_job_count: Union[Unset, int] = UNSET
    status: Union[Unset, ScalewayQaasV1Alpha1SessionStatus] = (
        ScalewayQaasV1Alpha1SessionStatus.UNKNOWN_STATUS
    )
    project_id: Union[Unset, str] = UNSET
    tags: Union[None, Unset, list[str]] = UNSET
    deduplication_id: Union[Unset, str] = UNSET
    origin_type: Union[Unset, ScalewayQaasV1Alpha1SessionOriginType] = (
        ScalewayQaasV1Alpha1SessionOriginType.UNKNOWN_ORIGIN_TYPE
    )
    origin_id: Union[None, Unset, str] = UNSET
    progress_message: Union[None, Unset, str] = UNSET
    booking_id: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        id = self.id

        name = self.name

        platform_id = self.platform_id

        created_at: Union[None, Unset, str]
        if isinstance(self.created_at, Unset):
            created_at = UNSET
        elif isinstance(self.created_at, datetime.datetime):
            created_at = self.created_at.isoformat()
        else:
            created_at = self.created_at

        started_at: Union[None, Unset, str]
        if isinstance(self.started_at, Unset):
            started_at = UNSET
        elif isinstance(self.started_at, datetime.datetime):
            started_at = self.started_at.isoformat()
        else:
            started_at = self.started_at

        updated_at: Union[None, Unset, str]
        if isinstance(self.updated_at, Unset):
            updated_at = UNSET
        elif isinstance(self.updated_at, datetime.datetime):
            updated_at = self.updated_at.isoformat()
        else:
            updated_at = self.updated_at

        terminated_at: Union[None, Unset, str]
        if isinstance(self.terminated_at, Unset):
            terminated_at = UNSET
        elif isinstance(self.terminated_at, datetime.datetime):
            terminated_at = self.terminated_at.isoformat()
        else:
            terminated_at = self.terminated_at

        max_idle_duration: Union[None, Unset, str]
        if isinstance(self.max_idle_duration, Unset):
            max_idle_duration = UNSET
        else:
            max_idle_duration = self.max_idle_duration

        max_duration: Union[None, Unset, str]
        if isinstance(self.max_duration, Unset):
            max_duration = UNSET
        else:
            max_duration = self.max_duration

        waiting_job_count = self.waiting_job_count

        finished_job_count = self.finished_job_count

        status: Union[Unset, str] = UNSET
        if not isinstance(self.status, Unset):
            status = self.status.value

        project_id = self.project_id

        tags: Union[None, Unset, list[str]]
        if isinstance(self.tags, Unset):
            tags = UNSET
        elif isinstance(self.tags, list):
            tags = self.tags

        else:
            tags = self.tags

        deduplication_id = self.deduplication_id

        origin_type: Union[Unset, str] = UNSET
        if not isinstance(self.origin_type, Unset):
            origin_type = self.origin_type.value

        origin_id: Union[None, Unset, str]
        if isinstance(self.origin_id, Unset):
            origin_id = UNSET
        else:
            origin_id = self.origin_id

        progress_message: Union[None, Unset, str]
        if isinstance(self.progress_message, Unset):
            progress_message = UNSET
        else:
            progress_message = self.progress_message

        booking_id: Union[None, Unset, str]
        if isinstance(self.booking_id, Unset):
            booking_id = UNSET
        else:
            booking_id = self.booking_id

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if id is not UNSET:
            field_dict["id"] = id
        if name is not UNSET:
            field_dict["name"] = name
        if platform_id is not UNSET:
            field_dict["platform_id"] = platform_id
        if created_at is not UNSET:
            field_dict["created_at"] = created_at
        if started_at is not UNSET:
            field_dict["started_at"] = started_at
        if updated_at is not UNSET:
            field_dict["updated_at"] = updated_at
        if terminated_at is not UNSET:
            field_dict["terminated_at"] = terminated_at
        if max_idle_duration is not UNSET:
            field_dict["max_idle_duration"] = max_idle_duration
        if max_duration is not UNSET:
            field_dict["max_duration"] = max_duration
        if waiting_job_count is not UNSET:
            field_dict["waiting_job_count"] = waiting_job_count
        if finished_job_count is not UNSET:
            field_dict["finished_job_count"] = finished_job_count
        if status is not UNSET:
            field_dict["status"] = status
        if project_id is not UNSET:
            field_dict["project_id"] = project_id
        if tags is not UNSET:
            field_dict["tags"] = tags
        if deduplication_id is not UNSET:
            field_dict["deduplication_id"] = deduplication_id
        if origin_type is not UNSET:
            field_dict["origin_type"] = origin_type
        if origin_id is not UNSET:
            field_dict["origin_id"] = origin_id
        if progress_message is not UNSET:
            field_dict["progress_message"] = progress_message
        if booking_id is not UNSET:
            field_dict["booking_id"] = booking_id

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        id = d.pop("id", UNSET)

        name = d.pop("name", UNSET)

        platform_id = d.pop("platform_id", UNSET)

        def _parse_created_at(data: object) -> Union[None, Unset, datetime.datetime]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                created_at_type_0 = isoparse(data)

                return created_at_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.datetime], data)

        created_at = _parse_created_at(d.pop("created_at", UNSET))

        def _parse_started_at(data: object) -> Union[None, Unset, datetime.datetime]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                started_at_type_0 = isoparse(data)

                return started_at_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.datetime], data)

        started_at = _parse_started_at(d.pop("started_at", UNSET))

        def _parse_updated_at(data: object) -> Union[None, Unset, datetime.datetime]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                updated_at_type_0 = isoparse(data)

                return updated_at_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.datetime], data)

        updated_at = _parse_updated_at(d.pop("updated_at", UNSET))

        def _parse_terminated_at(data: object) -> Union[None, Unset, datetime.datetime]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                terminated_at_type_0 = isoparse(data)

                return terminated_at_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.datetime], data)

        terminated_at = _parse_terminated_at(d.pop("terminated_at", UNSET))

        def _parse_max_idle_duration(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        max_idle_duration = _parse_max_idle_duration(d.pop("max_idle_duration", UNSET))

        def _parse_max_duration(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        max_duration = _parse_max_duration(d.pop("max_duration", UNSET))

        waiting_job_count = d.pop("waiting_job_count", UNSET)

        finished_job_count = d.pop("finished_job_count", UNSET)

        _status = d.pop("status", UNSET)
        status: Union[Unset, ScalewayQaasV1Alpha1SessionStatus]
        if isinstance(_status, Unset):
            status = UNSET
        else:
            status = ScalewayQaasV1Alpha1SessionStatus(_status)

        project_id = d.pop("project_id", UNSET)

        def _parse_tags(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                tags_type_0 = cast(list[str], data)

                return tags_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        tags = _parse_tags(d.pop("tags", UNSET))

        deduplication_id = d.pop("deduplication_id", UNSET)

        _origin_type = d.pop("origin_type", UNSET)
        origin_type: Union[Unset, ScalewayQaasV1Alpha1SessionOriginType]
        if isinstance(_origin_type, Unset):
            origin_type = UNSET
        else:
            origin_type = ScalewayQaasV1Alpha1SessionOriginType(_origin_type)

        def _parse_origin_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        origin_id = _parse_origin_id(d.pop("origin_id", UNSET))

        def _parse_progress_message(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        progress_message = _parse_progress_message(d.pop("progress_message", UNSET))

        def _parse_booking_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        booking_id = _parse_booking_id(d.pop("booking_id", UNSET))

        scaleway_qaas_v1_alpha_1_session = cls(
            id=id,
            name=name,
            platform_id=platform_id,
            created_at=created_at,
            started_at=started_at,
            updated_at=updated_at,
            terminated_at=terminated_at,
            max_idle_duration=max_idle_duration,
            max_duration=max_duration,
            waiting_job_count=waiting_job_count,
            finished_job_count=finished_job_count,
            status=status,
            project_id=project_id,
            tags=tags,
            deduplication_id=deduplication_id,
            origin_type=origin_type,
            origin_id=origin_id,
            progress_message=progress_message,
            booking_id=booking_id,
        )

        scaleway_qaas_v1_alpha_1_session.additional_properties = d
        return scaleway_qaas_v1_alpha_1_session

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class ListPlatformsOrderBy(str, Enum):
    BACKEND_NAME_ASC = "backend_name_asc"
    BACKEND_NAME_DESC = "backend_name_desc"
    NAME_ASC = "name_asc"
    NAME_DESC = "name_desc"
    PROVIDER_NAME_ASC = "provider_name_asc"
    PROVIDER_NAME_DESC = "provider_name_desc"
    TECHNOLOGY_ASC = "technology_asc"
    TECHNOLOGY_DESC = "technology_desc"
    TYPE_ASC = "type_asc"
    TYPE_DESC = "type_desc"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="CreateSessionBodyBookingDemand")


@_attrs_define
class CreateSessionBodyBookingDemand:
    """A booking demand to schedule the session, only applicable if the platform is bookable.

    Attributes:
        started_at (Union[None, Unset, datetime.datetime]): (RFC 3339 format) Example: 2022-03-22T12:34:56.123456Z.
        finished_at (Union[None, Unset, datetime.datetime]): (RFC 3339 format) Example: 2022-03-22T12:34:56.123456Z.
        description (Union[None, Unset, str]):
    """

    started_at: Union[None, Unset, datetime.datetime] = UNSET
    finished_at: Union[None, Unset, datetime.datetime] = UNSET
    description: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        started_at: Union[None, Unset, str]
        if isinstance(self.started_at, Unset):
            started_at = UNSET
        elif isinstance(self.started_at, datetime.datetime):
            started_at = self.started_at.isoformat()
        else:
            started_at = self.started_at

        finished_at: Union[None, Unset, str]
        if isinstance(self.finished_at, Unset):
            finished_at = UNSET
        elif isinstance(self.finished_at, datetime.datetime):
            finished_at = self.finished_at.isoformat()
        else:
            finished_at = self.finished_at

        description: Union[None, Unset, str]
        if isinstance(self.description, Unset):
            description = UNSET
        else:
            description = self.description

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if started_at is not UNSET:
            field_dict["started_at"] = started_at
        if finished_at is not UNSET:
            field_dict["finished_at"] = finished_at
        if description is not UNSET:
            field_dict["description"] = description

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)

        def _parse_started_at(data: object) -> Union[None, Unset, datetime.datetime]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                started_at_type_0 = isoparse(data)

                return started_at_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.datetime], data)

        started_at = _parse_started_at(d.pop("started_at", UNSET))

        def _parse_finished_at(data: object) -> Union[None, Unset, datetime.datetime]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                finished_at_type_0 = isoparse(data)

                return finished_at_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.datetime], data)

        finished_at = _parse_finished_at(d.pop("finished_at", UNSET))

        def _parse_description(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        description = _parse_description(d.pop("description", UNSET))

        create_session_body_booking_demand = cls(
            started_at=started_at,
            finished_at=finished_at,
            description=description,
        )

        create_session_body_booking_demand.additional_properties = d
        return create_session_body_booking_demand

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright 2025 Scaleway
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
import os
import time
import uuid

from scaleway_qaas_client import QaaSClient

_RANDOM_UUID = str(uuid.uuid4())
_TEST_PLATFORM_NAME = os.environ.get("TEST_PLATFORM_NAME", "aer_simulation_pop_c16m128")


def _get_client() -> QaaSClient:
    client = QaaSClient(
        project_id=os.environ["SCALEWAY_PROJECT_ID"],
        secret_key=os.environ["SCALEWAY_SECRET_KEY"],
        url=os.environ["SCALEWAY_API_URL"],
    )

    return client


def test_list_platform():
    client = _get_client()

    platforms = client.list_platforms()

    assert platforms is not None
    assert len(platforms) > 0


def test_create_delete_session():
    client = _get_client()

    platforms = client.list_platforms(name=_TEST_PLATFORM_NAME)

    assert platforms is not None
    assert len(platforms) == 1

    target_platform = platforms[0]

    assert target_platform.id is not None

    session = client.create_session(
        platform_id=target_platform.id, max_duration="2m", max_idle_duration="2m"
    )

    assert session is not None
    assert session.id is not None
    assert session.platform_id == target_platform.id

    while session.status == "starting":
        session = client.get_session(session.id)
        time.sleep(3)

    assert session.status == "running"

    session = client.terminate_session(session.id)

    while session.status == "stopping":
        session = client.get_session(session.id)
        time.sleep(3)

    assert session.status == "stopped"

    client.delete_session(session.id)


def test_list_platforms_by_backend(self):
    client = _get_client()

    platforms = client.list_platforms(backend_name="aer")

    assert len(platforms) > 0

    for platform in platforms:
        assert platform.backend_name == "aer"


def test_list_platforms_by_provider():
    client = _get_client()

    platforms = client.list_platforms(provider_name="quandela")

    assert len(platforms) > 0

    for platform in platforms:
        assert platform.provider_name == "quandela"


def test_list_platforms_by_unexisting_provider():
    client = _get_client()

    platforms = client.list_platforms(provider_name="aksjdkhjqw")

    assert platforms == []


def test_list_platforms_by_unexisting_backend():
    client = _get_client()

    platforms = client.list_platforms(backend_name="129837yiuhjdwksad")

    assert platforms == []


def test_list_platforms_by_name():
    client = _get_client()

    platforms = client.list_platforms(name=_TEST_PLATFORM_NAME)

    for platform in platforms:
        assert platform.name == _TEST_PLATFORM_NAME

    assert len(platforms) > 0


def test_list_platforms_by_unexisting_name():
    client = _get_client()

    platforms = client.list_platforms(name="w3219380ijskd")

    assert platforms == []


# def test_list_platforms_by_type(self):
#     type = PlatformType.SIMULATOR
#     platforms = self._client.list_platforms(type=type)

#     for platform in platforms:
#         assert platform.type == type
#     assert len(platforms) > 0

# def test_list_platforms_by_qpu_type(self):
#     plttype = PlatformType.QPU
#     platforms = self._client.list_platforms(type=plttype)

#     for platform in platforms:
#         assert platform.type == plttype

# def test_list_platforms_by_technology(self):
#     technology = PlatformTechnology.PHOTONIC
#     platforms = self._client.list_platforms(technology=technology)

#     for platform in platforms:
#         assert platform.technology == technology
#     assert len(platforms) > 0

# #
# # Applications tests
# #
# def test_list_applications(self):
#     applications = self._client.list_applications()

#     assert len(applications) > 0

# def test_list_applications_by_name(self):
#     name = self._APPLICATION_NAME
#     applications = self._client.list_applications(name=name)

#     for application in applications:
#         assert application.name == name
#     assert len(applications) > 0

# def test_get_application(self):
#     application = self._client.get_application(self._APPLICATION_ID)

#     assert self._PLATFORM_ID in application.compatible_platform_ids
#     assert application.id == self._APPLICATION_ID
#     assert application.name == self._APPLICATION_NAME

# def test_get_unexisting_application(self):
#     application = self._client.get_application(self._RANDOM_UUID)

#     assert application == None

# def test_list_applications_by_unexisting_name(self):
#     application = self._client.list_applications(name=random_name())

#     assert application == []

# def test_list_applications_by_type(self):
#     type = ApplicationType.VQE
#     applications = self._client.list_applications(type=type)

#     for application in applications:
#         assert application.type == type
#     assert len(applications) > 0

# def test_get_platform(self):
#     platform = self._client.get_platform(self._PLATFORM_ID)

#     assert platform.id == self._PLATFORM_ID

# def test_get_unexisting_platform(self):
#     platform = self._client.get_platform(self._RANDOM_UUID)

#     assert platform == None


# #
# # Session tests
# #
# def test_list_session_acl(self):
#     session_acls = self._client.list_session_acls(self._SESSION_ID)

#     assert session_acls == [SessionAcl.FULL.name.lower()]

# def test_create_session_with_unexisting_platform(self):
#     session = self._client.create_session(self._PROJECT_ID, self._RANDOM_UUID)

#     assert session == None

# def test_get_unexisting_session(self):
#     session = self._client.get_session(self._RANDOM_UUID)

#     assert session == None

# def test_delete_unexisting_session(self):
#     self._client.delete_session(self._RANDOM_UUID)

# def test_list_sessions_by_project_without_premission(self):
#     sessions = self._client.list_sessions(self._RANDOM_UUID)

#     assert sessions == []

# def test_list_sessions_unexisting_platform(self):
#     sessions = self._client.list_sessions(
#         self._PROJECT_ID, platform_id=self._RANDOM_UUID
#     )

#     assert sessions == []

# def test_get_session(self):
#     session = self._client.get_session(self._SESSION_ID)

#     assert session != None
#     assert session.id == self._SESSION_ID
#     assert session.project_id == self._PROJECT_ID
#     assert session.platform_id == self._PLATFORM_ID
#     assert session.name == self._SESSION_NAME
#     assert session.max_duration == self._SESSION_MAX_DURATION
#     assert session.max_idle_duration == self._SESSION_MAX_IDLE_DURATION
#     assert session.status in [SessionStatus.STARTING, SessionStatus.RUNNING]
#     assert session.deduplication_id == self._SESSION_DEDUPLICATION_ID
#     assert session.tags == self._SESSION_TAGS

# def test_list_sessions_by_project(self):
#     process = self._client.create_process(
#         self._PROJECT_ID,
#         self._PLATFORM_ID,
#         self._APPLICATION_ID,
#         self._PROCESS_NAME,
#     )

#     # Wait that the process create some sessions
#     sessions = None
#     while sessions is None or len(sessions) == 0:
#         sessions = self._client.list_sessions(self._PROJECT_ID)
#         time.sleep(2)

#     assert sessions != None
#     assert len(sessions) > 0

#     session_found = None
#     session_from_process_found = False
#     for session in sessions:
#         if session.id == self._SESSION_ID:
#             session_found = session
#         if session.origin_id == process.id:
#             session_from_process_found = True

#     assert session_from_process_found == False
#     assert session_found is not None
#     assert session_found.project_id == self._PROJECT_ID
#     assert session_found.platform_id == self._PLATFORM_ID
#     assert session_found.name == self._SESSION_NAME
#     assert session_found.max_duration == self._SESSION_MAX_DURATION
#     assert session_found.max_idle_duration == self._SESSION_MAX_IDLE_DURATION
#     assert session_found.status in [SessionStatus.STARTING, SessionStatus.RUNNING]
#     assert session_found.deduplication_id == self._SESSION_DEDUPLICATION_ID
#     assert session_found.tags == self._SESSION_TAGS

# def test_list_sessions_by_platform(self):
#     sessions = self._client.list_sessions(
#         self._PROJECT_ID, platform_id=self._PLATFORM_ID
#     )

#     assert sessions != None
#     assert len(sessions) > 0

#     session_found = False
#     for session in sessions:
#         if session.id == self._SESSION_ID:
#             session_found = True
#             break

#     assert session_found == True
#     assert session.project_id == self._PROJECT_ID
#     assert session.platform_id == self._PLATFORM_ID
#     assert session.name == self._SESSION_NAME
#     assert session.max_duration == self._SESSION_MAX_DURATION
#     assert session.max_idle_duration == self._SESSION_MAX_IDLE_DURATION
#     assert session.status in [SessionStatus.STARTING, SessionStatus.RUNNING]
#     assert session.deduplication_id == self._SESSION_DEDUPLICATION_ID
#     assert session.tags == self._SESSION_TAGS

# def test_create_session_same_deduplication_id(self):
#     session = self._client.create_session(
#         project_id=self._PROJECT_ID,
#         platform_id=self._PLATFORM_ID,
#         deduplication_id=self._SESSION_DEDUPLICATION_ID,
#     )

#     assert session != None
#     assert session.id == self._SESSION_ID
#     assert session.project_id == self._PROJECT_ID
#     assert session.platform_id == self._PLATFORM_ID
#     assert session.name == self._SESSION_NAME
#     assert session.max_duration == self._SESSION_MAX_DURATION
#     assert session.max_idle_duration == self._SESSION_MAX_IDLE_DURATION
#     assert session.status in [SessionStatus.STARTING, SessionStatus.RUNNING]
#     assert session.deduplication_id == self._SESSION_DEDUPLICATION_ID
#     # assert session.tags == self._SESSION_TAGS

# def test_update_session(self):
#     self._SESSION_NAME = "poney"
#     self._SESSION_MAX_DURATION = "555s"
#     self._SESSION_MAX_IDLE_DURATION = "555s"
#     session = self._client.update_session(
#         self._SESSION_ID,
#         name=self._SESSION_NAME,
#         max_duration=self._SESSION_MAX_DURATION,
#         max_idle_duration=self._SESSION_MAX_IDLE_DURATION,
#     )

#     assert session != None
#     assert session.project_id == self._PROJECT_ID
#     assert session.platform_id == self._PLATFORM_ID
#     assert session.name == self._SESSION_NAME
#     assert session.max_duration == self._SESSION_MAX_DURATION
#     assert session.max_idle_duration == self._SESSION_MAX_IDLE_DURATION
#     assert session.deduplication_id == self._SESSION_DEDUPLICATION_ID

#     session = self._client.get_session(self._SESSION_ID)

#     assert session != None
#     assert session.project_id == self._PROJECT_ID
#     assert session.platform_id == self._PLATFORM_ID
#     assert session.name == self._SESSION_NAME
#     assert session.max_duration == self._SESSION_MAX_DURATION
#     assert session.max_idle_duration == self._SESSION_MAX_IDLE_DURATION
#     assert session.deduplication_id == self._SESSION_DEDUPLICATION_ID

# def test_update_session_tags(self):
#     tags = ["updated", "other"]
#     session = self._client.update_session(self._SESSION_ID, tags=tags)

#     assert session != None
#     assert session.project_id == self._PROJECT_ID
#     assert session.platform_id == self._PLATFORM_ID
#     assert session.deduplication_id == self._SESSION_DEDUPLICATION_ID
#     assert session.tags == tags

#     session = self._client.get_session(self._SESSION_ID)

#     assert session != None
#     assert session.project_id == self._PROJECT_ID
#     assert session.platform_id == self._PLATFORM_ID
#     assert session.deduplication_id == self._SESSION_DEDUPLICATION_ID
#     assert session.tags == tags

# def test_remove_session_tags(self):
#     tags = []
#     session = self._client.update_session(self._SESSION_ID, tags=tags)

#     assert session != None
#     assert session.project_id == self._PROJECT_ID
#     assert session.platform_id == self._PLATFORM_ID
#     assert session.deduplication_id == self._SESSION_DEDUPLICATION_ID
#     assert session.tags == tags

#     session = self._client.get_session(self._SESSION_ID)

#     assert session != None
#     assert session.project_id == self._PROJECT_ID
#     assert session.platform_id == self._PLATFORM_ID
#     assert session.deduplication_id == self._SESSION_DEDUPLICATION_ID
#     assert session.tags == tags

# #
# # Job tests
# #
# def test_create_job_with_unexisting_session(self):
#     name = random_name()
#     circuit = {"perceval_circuit": self._PERCEVAL_CIRCUIT}
#     job = self._client.create_job(name, self._RANDOM_UUID, circuit)

#     assert job == None

# def test_get_unexisting_job(self):
#     job = self._client.get_job(self._RANDOM_UUID)

#     assert job == None

# def test_update_unexisting_job(self):
#     job = self._client.update_job(self._RANDOM_UUID, name="toto")

#     assert job == None

# def test_cancel_unexisting_job(self):
#     job = self._client.cancel_job(self._RANDOM_UUID)

#     assert job == None



# Copyright 2025 Scaleway
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
import json
from typing import Dict, List, Optional, Union

import randomname
from pytimeparse.timeparse import timeparse

from scaleway_qaas_client.quantum_as_a_service_api_client.api.jobs.cancel_job import (
    sync_detailed as _cancel_job_sync,
)
from scaleway_qaas_client.quantum_as_a_service_api_client.api.jobs.create_job import (
    sync_detailed as _create_job_sync,
)
from scaleway_qaas_client.quantum_as_a_service_api_client.api.jobs.get_job import (
    sync_detailed as _get_job_sync,
)
from scaleway_qaas_client.quantum_as_a_service_api_client.api.jobs.list_job_results import (
    sync_detailed as _list_job_result_sync,
)
from scaleway_qaas_client.quantum_as_a_service_api_client.api.platforms.get_platform import (
    sync_detailed as _get_platform_sync,
)
from scaleway_qaas_client.quantum_as_a_service_api_client.api.platforms.list_platforms import (
    sync_detailed as _list_platforms_sync,
)
from scaleway_qaas_client.quantum_as_a_service_api_client.api.sessions.create_session import (
    sync_detailed as _create_session_sync,
)
from scaleway_qaas_client.quantum_as_a_service_api_client.api.sessions.delete_session import (
    sync_detailed as _delete_session_sync,
)
from scaleway_qaas_client.quantum_as_a_service_api_client.api.sessions.get_session import (
    sync_detailed as _get_session_sync,
)
from scaleway_qaas_client.quantum_as_a_service_api_client.api.sessions.list_sessions import (
    sync_detailed as _list_sessions_sync,
)
from scaleway_qaas_client.quantum_as_a_service_api_client.api.sessions.terminate_session import (
    sync_detailed as _terminate_session_sync,
)
from scaleway_qaas_client.quantum_as_a_service_api_client.client import (
    AuthenticatedClient,
)
from scaleway_qaas_client.quantum_as_a_service_api_client.models import (
    CancelJobBody,
    CreateJobBody,
    CreateJobBodyCircuit,
    CreateSessionBody,
    ScalewayQaasV1Alpha1Job,
    ScalewayQaasV1Alpha1JobResult,
    ScalewayQaasV1Alpha1Platform,
    ScalewayQaasV1Alpha1Session,
    TerminateSessionBody,
)
from scaleway_qaas_client.quantum_as_a_service_api_client.types import Response

_DEFAULT_URL = "https://api.scaleway.com"


def _raise_on_error(response: Response):
    if not response:
        raise Exception("error: None response")

    if response.status_code.is_server_error or response.status_code.is_client_error:
        raise Exception(
            f"error {response.status_code}: {response.content.decode('utf-8')}"
        )


class QaaSClient:
    def __init__(self, project_id: str, secret_key: str, url: str = _DEFAULT_URL):
        if not project_id:
            raise Exception("QaasClient: project_id cannot be None")

        if not secret_key:
            raise Exception("QaasClient: secret_key cannot be None")

        self.__project_id = project_id
        url = url if url else _DEFAULT_URL

        self.__client = AuthenticatedClient(
            base_url=url,
            timeout=10.0,
            verify_ssl="https" in url,
            token=secret_key,
            prefix=None,
            auth_header_name="X-Auth-Token",
        )

    def __repr__(self) -> str:
        return f"<QaaSClient(url={self.__client._base_url},project_id={self.__project_id})>"

    def get_platform(self, platform_id: str) -> ScalewayQaasV1Alpha1Platform:
        """Get platform information

        Retrieve information about the provided **platform ID**, such as provider name, technology, and
        type.

        Args:
            platform_id (str): Unique ID of the platform.

        Raises:
            errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
            httpx.TimeoutException: If the request takes longer than Client.timeout.

        Returns:
            ScalewayQaasV1Alpha1Platform
        """

        if not platform_id:
            raise Exception("get_platform: platform_id cannot be None")

        response = _get_platform_sync(client=self.__client, platform_id=platform_id)

        _raise_on_error(response)

        return response.parsed

    def list_platforms(
        self,
        name: Optional[str] = None,
        backend_name: Optional[str] = None,
        provider_name: Optional[str] = None,
    ) -> List[ScalewayQaasV1Alpha1Platform]:
        """List all available platforms

        Retrieve information about all platforms.

        Args:
            name (Union[Unset, str]): List platforms with this name.

        Raises:
            errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
            httpx.TimeoutException: If the request takes longer than Client.timeout.

        Returns:
            List[ScalewayQaasV1Alpha1ListPlatforms]
        """

        response = _list_platforms_sync(
            client=self.__client,
            name=name,
            provider_name=provider_name,
            backend_name=backend_name,
        )

        _raise_on_error(response)

        return response.parsed.platforms

    def create_session(
        self,
        platform_id: str,
        max_duration: Union[str, int],
        max_idle_duration: Union[str, int],
        deduplication_id: Optional[str] = None,
        name: Optional[str] = None,
    ) -> ScalewayQaasV1Alpha1Session:
        """Create a session

        Create a dedicated session for the specified platform.

        Args:
            body (CreateSessionBody):

        Raises:
            errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
            httpx.TimeoutException: If the request takes longer than Client.timeout.

        Returns:
            ScalewayQaasV1Alpha1Session
        """

        if not platform_id:
            raise Exception("create_session: platform_id cannot be None")

        name = name if name else f"qs-{randomname.get_name()}"

        if isinstance(max_duration, str):
            max_duration = f"{timeparse(max_duration)}s"

        if isinstance(max_idle_duration, str):
            max_idle_duration = f"{timeparse(max_idle_duration)}s"

        response = _create_session_sync(
            client=self.__client,
            body=CreateSessionBody(
                project_id=self.__project_id,
                name=name,
                platform_id=platform_id,
                deduplication_id=deduplication_id,
                max_duration=max_duration,
                max_idle_duration=max_idle_duration,
            ),
        )

        _raise_on_error(response)

        return response.parsed

    def get_session(self, session_id: str) -> ScalewayQaasV1Alpha1Session:
        """Get session information

        Retrieve information about the provided **session ID**, such as name, status, and number of executed
        jobs.

        Args:
            session_id (str): Unique ID of the session.

        Raises:
            errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
            httpx.TimeoutException: If the request takes longer than Client.timeout.

        Returns:
            ScalewayQaasV1Alpha1Session
        """

        if not session_id:
            raise Exception("get_session: session_id cannot be None")

        response = _get_session_sync(client=self.__client, session_id=session_id)

        _raise_on_error(response)

        return response.parsed

    def list_sessions(
        self, platform_id: Optional[str] = None
    ) -> List[ScalewayQaasV1Alpha1Session]:
        """List all sessions

        Retrieve information about all sessions.

        Args:
            platform_id (Union[Unset, str]): List sessions that have been created for this platform.
            tags (Union[Unset, list[str]]): List sessions with these tags.
            page (Union[Unset, int]): Page number.
            page_size (Union[Unset, int]): Maximum number of sessions to return per page.
            order_by (Union[Unset, ListSessionsOrderBy]): Sort order of the returned sessions.
                Default: ListSessionsOrderBy.NAME_ASC.
            project_id (str): List sessions belonging to this project ID. (UUID format) Example:
                6170692e-7363-616c-6577-61792e636f6d.

        Raises:
            errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
            httpx.TimeoutException: If the request takes longer than Client.timeout.

        Returns:
            List[ScalewayQaasV1Alpha1ListSessionsResponse]
        """

        if not platform_id:
            raise Exception("list_session: platform_id cannot be None")

        response = _list_sessions_sync(
            client=self.__client, project_id=self.__project_id, platform_id=platform_id
        )

        _raise_on_error(response)

        return response.parsed.sessions

    def terminate_session(self, session_id: str) -> ScalewayQaasV1Alpha1Session:
        """Terminate an existing session

        Terminate a session by its unique ID and cancel all its attached jobs and booking.

        Args:
            session_id (str): Unique ID of the session.
            body (TerminateSessionBody):

        Raises:
            errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
            httpx.TimeoutException: If the request takes longer than Client.timeout.

        Returns:
            ScalewayQaasV1Alpha1Session
        """

        if not session_id:
            raise Exception("terminate_session: session_id cannot be None")

        response = _terminate_session_sync(
            client=self.__client,
            session_id=session_id,
            body=TerminateSessionBody(),
        )

        _raise_on_error(response)

        return response.parsed

    def delete_session(self, session_id: str):
        """Delete an existing session

        Delete a session by its unique ID and delete all its attached job and booking.

        Args:
            session_id (str): Unique ID of the session.

        Raises:
            errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
            httpx.TimeoutException: If the request takes longer than Client.timeout.
        """

        if not session_id:
            raise Exception("delete_session: session_id cannot be None")

        _delete_session_sync(client=self.__client, session_id=session_id)

    def create_job(
        self,
        session_id: str,
        payload: Union[Dict, List, str],
        name: Optional[str] = None,
    ) -> ScalewayQaasV1Alpha1Job:
        """Create a job

        Create a job to be executed inside a session.

        Args:
            body (CreateJobBody):

        Raises:
            errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
            httpx.TimeoutException: If the request takes longer than Client.timeout.

        Returns:
            ScalewayQaasV1Alpha1Job
        """

        if not session_id:
            raise Exception("create_job: session_id cannot be None")

        if not payload:
            raise Exception("create_job: payload cannot be None")

        payload = payload if isinstance(payload, str) else json.dumps(payload)
        name = name if name else f"qj-{randomname.get_name()}"

        response = _create_job_sync(
            client=self.__client,
            body=CreateJobBody(
                name=name,
                session_id=session_id,
                circuit=CreateJobBodyCircuit(qiskit_circuit=payload),
            ),
        )

        _raise_on_error(response)

        return response.parsed

    def get_job(self, job_id: str) -> ScalewayQaasV1Alpha1Job:
        """Get job information

        Retrieve information about the provided **job ID**, such as status, payload, and result.

        Args:
            job_id (str): Unique ID of the job you want to get.

        Raises:
            errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
            httpx.TimeoutException: If the request takes longer than Client.timeout.

        Returns:
            ScalewayQaasV1Alpha1Job
        """

        if not job_id:
            raise Exception("get_job: job_id cannot be None")

        response = _get_job_sync(client=self.__client, job_id=job_id)

        _raise_on_error(response)

        return response.parsed

    def list_job_results(self, job_id: str) -> List[ScalewayQaasV1Alpha1JobResult]:
        """List all results of a job

        Retrieve all intermediate and final results of a job.

        Args:
            job_id (str): ID of the job.

        Raises:
            errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
            httpx.TimeoutException: If the request takes longer than Client.timeout.

        Returns:
            List[ScalewayQaasV1Alpha1ListJobResultsResponse]
        """

        if not job_id:
            raise Exception("list_job_results: job_id cannot be None")

        response = _list_job_result_sync(client=self.__client, job_id=job_id)

        _raise_on_error(response)

        return response.parsed.job_results

    def cancel_job(self, job_id: str) -> ScalewayQaasV1Alpha1Job:
        """Cancel a job

        Cancel the job corresponding to the provided **job ID**.

        Args:
            job_id (str): Unique ID of the job.
            body (CancelJobBody):

        Raises:
            errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
            httpx.TimeoutException: If the request takes longer than Client.timeout.

        Returns:
            ScalewayQaasV1Alpha1Job
        """

        if not job_id:
            raise Exception("cancel_job: job_id cannot be None")

        response = _cancel_job_sync(
            client=self.__client,
            job_id=job_id,
            body=CancelJobBody(),
        )

        _raise_on_error(response)

        return response.parsed



from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.list_sessions_order_by import ListSessionsOrderBy
from ...models.scaleway_qaas_v1_alpha_1_list_sessions_response import (
    ScalewayQaasV1Alpha1ListSessionsResponse,
)
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    platform_id: Union[Unset, str] = UNSET,
    tags: Union[Unset, list[str]] = UNSET,
    page: Union[Unset, int] = UNSET,
    page_size: Union[Unset, int] = UNSET,
    order_by: Union[Unset, ListSessionsOrderBy] = ListSessionsOrderBy.NAME_ASC,
    project_id: str,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    params["platform_id"] = platform_id

    json_tags: Union[Unset, list[str]] = UNSET
    if not isinstance(tags, Unset):
        json_tags = tags

    params["tags"] = json_tags

    params["page"] = page

    params["page_size"] = page_size

    json_order_by: Union[Unset, str] = UNSET
    if not isinstance(order_by, Unset):
        json_order_by = order_by.value

    params["order_by"] = json_order_by

    params["project_id"] = project_id

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": "/qaas/v1alpha1/sessions",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[ScalewayQaasV1Alpha1ListSessionsResponse]:
    if response.status_code == 200:
        response_200 = ScalewayQaasV1Alpha1ListSessionsResponse.from_dict(
            response.json()
        )

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[ScalewayQaasV1Alpha1ListSessionsResponse]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    platform_id: Union[Unset, str] = UNSET,
    tags: Union[Unset, list[str]] = UNSET,
    page: Union[Unset, int] = UNSET,
    page_size: Union[Unset, int] = UNSET,
    order_by: Union[Unset, ListSessionsOrderBy] = ListSessionsOrderBy.NAME_ASC,
    project_id: str,
) -> Response[ScalewayQaasV1Alpha1ListSessionsResponse]:
    """List all sessions

     Retrieve information about all sessions.

    Args:
        platform_id (Union[Unset, str]): List sessions that have been created for this platform.
        tags (Union[Unset, list[str]]): List sessions with these tags.
        page (Union[Unset, int]): Page number.
        page_size (Union[Unset, int]): Maximum number of sessions to return per page.
        order_by (Union[Unset, ListSessionsOrderBy]): Sort order of the returned sessions.
            Default: ListSessionsOrderBy.NAME_ASC.
        project_id (str): List sessions belonging to this project ID. (UUID format) Example:
            6170692e-7363-616c-6577-61792e636f6d.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[ScalewayQaasV1Alpha1ListSessionsResponse]
    """

    kwargs = _get_kwargs(
        platform_id=platform_id,
        tags=tags,
        page=page,
        page_size=page_size,
        order_by=order_by,
        project_id=project_id,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: AuthenticatedClient,
    platform_id: Union[Unset, str] = UNSET,
    tags: Union[Unset, list[str]] = UNSET,
    page: Union[Unset, int] = UNSET,
    page_size: Union[Unset, int] = UNSET,
    order_by: Union[Unset, ListSessionsOrderBy] = ListSessionsOrderBy.NAME_ASC,
    project_id: str,
) -> Optional[ScalewayQaasV1Alpha1ListSessionsResponse]:
    """List all sessions

     Retrieve information about all sessions.

    Args:
        platform_id (Union[Unset, str]): List sessions that have been created for this platform.
        tags (Union[Unset, list[str]]): List sessions with these tags.
        page (Union[Unset, int]): Page number.
        page_size (Union[Unset, int]): Maximum number of sessions to return per page.
        order_by (Union[Unset, ListSessionsOrderBy]): Sort order of the returned sessions.
            Default: ListSessionsOrderBy.NAME_ASC.
        project_id (str): List sessions belonging to this project ID. (UUID format) Example:
            6170692e-7363-616c-6577-61792e636f6d.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        ScalewayQaasV1Alpha1ListSessionsResponse
    """

    return sync_detailed(
        client=client,
        platform_id=platform_id,
        tags=tags,
        page=page,
        page_size=page_size,
        order_by=order_by,
        project_id=project_id,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    platform_id: Union[Unset, str] = UNSET,
    tags: Union[Unset, list[str]] = UNSET,
    page: Union[Unset, int] = UNSET,
    page_size: Union[Unset, int] = UNSET,
    order_by: Union[Unset, ListSessionsOrderBy] = ListSessionsOrderBy.NAME_ASC,
    project_id: str,
) -> Response[ScalewayQaasV1Alpha1ListSessionsResponse]:
    """List all sessions

     Retrieve information about all sessions.

    Args:
        platform_id (Union[Unset, str]): List sessions that have been created for this platform.
        tags (Union[Unset, list[str]]): List sessions with these tags.
        page (Union[Unset, int]): Page number.
        page_size (Union[Unset, int]): Maximum number of sessions to return per page.
        order_by (Union[Unset, ListSessionsOrderBy]): Sort order of the returned sessions.
            Default: ListSessionsOrderBy.NAME_ASC.
        project_id (str): List sessions belonging to this project ID. (UUID format) Example:
            6170692e-7363-616c-6577-61792e636f6d.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[ScalewayQaasV1Alpha1ListSessionsResponse]
    """

    kwargs = _get_kwargs(
        platform_id=platform_id,
        tags=tags,
        page=page,
        page_size=page_size,
        order_by=order_by,
        project_id=project_id,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    platform_id: Union[Unset, str] = UNSET,
    tags: Union[Unset, list[str]] = UNSET,
    page: Union[Unset, int] = UNSET,
    page_size: Union[Unset, int] = UNSET,
    order_by: Union[Unset, ListSessionsOrderBy] = ListSessionsOrderBy.NAME_ASC,
    project_id: str,
) -> Optional[ScalewayQaasV1Alpha1ListSessionsResponse]:
    """List all sessions

     Retrieve information about all sessions.

    Args:
        platform_id (Union[Unset, str]): List sessions that have been created for this platform.
        tags (Union[Unset, list[str]]): List sessions with these tags.
        page (Union[Unset, int]): Page number.
        page_size (Union[Unset, int]): Maximum number of sessions to return per page.
        order_by (Union[Unset, ListSessionsOrderBy]): Sort order of the returned sessions.
            Default: ListSessionsOrderBy.NAME_ASC.
        project_id (str): List sessions belonging to this project ID. (UUID format) Example:
            6170692e-7363-616c-6577-61792e636f6d.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        ScalewayQaasV1Alpha1ListSessionsResponse
    """

    return (
        await asyncio_detailed(
            client=client,
            platform_id=platform_id,
            tags=tags,
            page=page,
            page_size=page_size,
            order_by=order_by,
            project_id=project_id,
        )
    ).parsed



import datetime
from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="ScalewayQaasV1Alpha1ProcessResult")


@_attrs_define
class ScalewayQaasV1Alpha1ProcessResult:
    """
    Attributes:
        process_id (Union[Unset, str]): ID of the parent process.
        result (Union[Unset, str]): Result in JSON format.
        created_at (Union[None, Unset, datetime.datetime]): Creation time of the result. (RFC 3339 format) Example:
            2022-03-22T12:34:56.123456Z.
    """

    process_id: Union[Unset, str] = UNSET
    result: Union[Unset, str] = UNSET
    created_at: Union[None, Unset, datetime.datetime] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        process_id = self.process_id

        result = self.result

        created_at: Union[None, Unset, str]
        if isinstance(self.created_at, Unset):
            created_at = UNSET
        elif isinstance(self.created_at, datetime.datetime):
            created_at = self.created_at.isoformat()
        else:
            created_at = self.created_at

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if process_id is not UNSET:
            field_dict["process_id"] = process_id
        if result is not UNSET:
            field_dict["result"] = result
        if created_at is not UNSET:
            field_dict["created_at"] = created_at

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        process_id = d.pop("process_id", UNSET)

        result = d.pop("result", UNSET)

        def _parse_created_at(data: object) -> Union[None, Unset, datetime.datetime]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                created_at_type_0 = isoparse(data)

                return created_at_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.datetime], data)

        created_at = _parse_created_at(d.pop("created_at", UNSET))

        scaleway_qaas_v1_alpha_1_process_result = cls(
            process_id=process_id,
            result=result,
            created_at=created_at,
        )

        scaleway_qaas_v1_alpha_1_process_result.additional_properties = d
        return scaleway_qaas_v1_alpha_1_process_result

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright 2025 Scaleway
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
from .client import QaaSClient
from .job_payload.models import (
    QaaSCircuitData,
    QaaSCircuitSerializationFormat,
    QaaSJobBackendData,
    QaaSJobClientData,
    QaaSJobData,
    QaaSJobRunData,
)
from .quantum_as_a_service_api_client.models import (
    ScalewayQaasV1Alpha1Application as QaaSApplication,
)
from .quantum_as_a_service_api_client.models import ScalewayQaasV1Alpha1Job as QaaSJob
from .quantum_as_a_service_api_client.models import (
    ScalewayQaasV1Alpha1JobResult as QaaSJobResult,
)
from .quantum_as_a_service_api_client.models import (
    ScalewayQaasV1Alpha1JobResult as QaaSJobResut,
)
from .quantum_as_a_service_api_client.models import (
    ScalewayQaasV1Alpha1JobStatus as QaaSJobStatus,
)
from .quantum_as_a_service_api_client.models import (
    ScalewayQaasV1Alpha1Platform as QaaSPlatform,
)
from .quantum_as_a_service_api_client.models import (
    ScalewayQaasV1Alpha1PlatformAvailability as QaaSPlatformAvailability,
)
from .quantum_as_a_service_api_client.models import (
    ScalewayQaasV1Alpha1PlatformTechnology as QaaSPlatformTechnology,
)
from .quantum_as_a_service_api_client.models import (
    ScalewayQaasV1Alpha1Process as QaaSProcess,
)
from .quantum_as_a_service_api_client.models import (
    ScalewayQaasV1Alpha1ProcessResult as QaaSProcessResult,
)
from .quantum_as_a_service_api_client.models import (
    ScalewayQaasV1Alpha1ProcessStatus as QaaSProcessStatus,
)
from .quantum_as_a_service_api_client.models import (
    ScalewayQaasV1Alpha1Session as QaaSSession,
)
from .quantum_as_a_service_api_client.models import (
    ScalewayQaasV1Alpha1SessionStatus as QaaSSessionStatus,
)



from enum import Enum


class ListPlatformsPlatformTechnology(str, Enum):
    GENERAL_PURPOSE = "general_purpose"
    NEUTRAL_ATOM = "neutral_atom"
    PHOTONIC = "photonic"
    SUPERCONDUCTING = "superconducting"
    TRAPPED_ION = "trapped_ion"
    UNKNOWN_TECHNOLOGY = "unknown_technology"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class ScalewayQaasV1Alpha1BookingStatus(str, Enum):
    CANCELLED = "cancelled"
    CANCELLING = "cancelling"
    ERROR = "error"
    UNKNOWN_STATUS = "unknown_status"
    VALIDATED = "validated"
    VALIDATING = "validating"
    WAITING = "waiting"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="CreateProcessBody")


@_attrs_define
class CreateProcessBody:
    """
    Attributes:
        project_id (str): ID of the project in which the process was created. (UUID format) Example:
            6170692e-7363-616c-6577-61792e636f6d.
        platform_id (Union[None, str]): ID of the platform for which the process was created.
        application_id (Union[None, str]): ID of the application for which the process was created.
        name (Union[Unset, str]): Name of the process.
        input_ (Union[None, Unset, str]): Process parameters in JSON format.
        tags (Union[Unset, list[str]]): Tags of the process.
    """

    project_id: str
    platform_id: Union[None, str]
    application_id: Union[None, str]
    name: Union[Unset, str] = UNSET
    input_: Union[None, Unset, str] = UNSET
    tags: Union[Unset, list[str]] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        project_id = self.project_id

        platform_id: Union[None, str]
        platform_id = self.platform_id

        application_id: Union[None, str]
        application_id = self.application_id

        name = self.name

        input_: Union[None, Unset, str]
        if isinstance(self.input_, Unset):
            input_ = UNSET
        else:
            input_ = self.input_

        tags: Union[Unset, list[str]] = UNSET
        if not isinstance(self.tags, Unset):
            tags = self.tags

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "project_id": project_id,
                "platform_id": platform_id,
                "application_id": application_id,
            }
        )
        if name is not UNSET:
            field_dict["name"] = name
        if input_ is not UNSET:
            field_dict["input"] = input_
        if tags is not UNSET:
            field_dict["tags"] = tags

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        project_id = d.pop("project_id")

        def _parse_platform_id(data: object) -> Union[None, str]:
            if data is None:
                return data
            return cast(Union[None, str], data)

        platform_id = _parse_platform_id(d.pop("platform_id"))

        def _parse_application_id(data: object) -> Union[None, str]:
            if data is None:
                return data
            return cast(Union[None, str], data)

        application_id = _parse_application_id(d.pop("application_id"))

        name = d.pop("name", UNSET)

        def _parse_input_(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        input_ = _parse_input_(d.pop("input", UNSET))

        tags = cast(list[str], d.pop("tags", UNSET))

        create_process_body = cls(
            project_id=project_id,
            platform_id=platform_id,
            application_id=application_id,
            name=name,
            input_=input_,
            tags=tags,
        )

        create_process_body.additional_properties = d
        return create_process_body

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class ListJobsOrderBy(str, Enum):
    CREATED_AT_ASC = "created_at_asc"
    CREATED_AT_DESC = "created_at_desc"
    NAME_ASC = "name_asc"
    NAME_DESC = "name_desc"
    PLATFORM_NAME_ASC = "platform_name_asc"
    PLATFORM_NAME_DESC = "platform_name_desc"
    SESSION_NAME_ASC = "session_name_asc"
    SESSION_NAME_DESC = "session_name_desc"
    STATUS_ASC = "status_asc"
    STATUS_DESC = "status_desc"

    def __str__(self) -> str:
        return str(self.value)



# Copyright 2024 Scaleway
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import io
from setuptools import setup, find_packages

description = ("Python client providing primitives to be used from other quantum SDKs",)
long_description = io.open("README.md", encoding="utf-8").read()
requirements = open("requirements.txt").readlines()
requirements = [r.strip() for r in requirements]

setup(
    name="scaleway_qaas_client",
    version="0.1.12",
    project_urls={
        "Documentation": "https://www.scaleway.com/en/quantum-as-a-service/",
        "Source": "https://github.com/scaleway/scaleway-qaas-client-pythom",
        "Tracker": "https://github.com/scaleway/scaleway-qaas-client-pythom/issues",
    },
    author="The Scaleway Developers",
    author_email="vmacheret@scaleway.com",
    packages=find_packages(),
    install_requires=requirements,
    python_requires=(">=3.12.0"),
    license="Apache 2",
    description=description,
    long_description=long_description,
    long_description_content_type="text/markdown",
)



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="ScalewayQaasV1Alpha1PlatformHardware")


@_attrs_define
class ScalewayQaasV1Alpha1PlatformHardware:
    """Specifications of the underlying hardware.

    Attributes:
        name (Union[Unset, str]): Product name of the hardware.
        vcpus (Union[Unset, int]): Number of vCPUs available.
        gpus (Union[Unset, int]): Number of GPUs available (0 if no GPU).
        gpus_network (Union[Unset, str]): Network topology of GPUs (PCIe, NVLink...).
        ram (Union[Unset, int]): Amount of RAM available in byte.
        vram (Union[Unset, int]): Amount of VRAM available in byte (0 if no GPU).
    """

    name: Union[Unset, str] = UNSET
    vcpus: Union[Unset, int] = UNSET
    gpus: Union[Unset, int] = UNSET
    gpus_network: Union[Unset, str] = UNSET
    ram: Union[Unset, int] = UNSET
    vram: Union[Unset, int] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        name = self.name

        vcpus = self.vcpus

        gpus = self.gpus

        gpus_network = self.gpus_network

        ram = self.ram

        vram = self.vram

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if name is not UNSET:
            field_dict["name"] = name
        if vcpus is not UNSET:
            field_dict["vcpus"] = vcpus
        if gpus is not UNSET:
            field_dict["gpus"] = gpus
        if gpus_network is not UNSET:
            field_dict["gpus_network"] = gpus_network
        if ram is not UNSET:
            field_dict["ram"] = ram
        if vram is not UNSET:
            field_dict["vram"] = vram

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        name = d.pop("name", UNSET)

        vcpus = d.pop("vcpus", UNSET)

        gpus = d.pop("gpus", UNSET)

        gpus_network = d.pop("gpus_network", UNSET)

        ram = d.pop("ram", UNSET)

        vram = d.pop("vram", UNSET)

        scaleway_qaas_v1_alpha_1_platform_hardware = cls(
            name=name,
            vcpus=vcpus,
            gpus=gpus,
            gpus_network=gpus_network,
            ram=ram,
            vram=vram,
        )

        scaleway_qaas_v1_alpha_1_platform_hardware.additional_properties = d
        return scaleway_qaas_v1_alpha_1_platform_hardware

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="ScalewayQaasV1Alpha1JobCircuit")


@_attrs_define
class ScalewayQaasV1Alpha1JobCircuit:
    """
    Attributes:
        perceval_circuit (Union[None, Unset, str]): Circuit generated by Perceval that should be executed.
        qiskit_circuit (Union[None, Unset, str]): Circuit generated by Qiskit that should be executed.
    """

    perceval_circuit: Union[None, Unset, str] = UNSET
    qiskit_circuit: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        perceval_circuit: Union[None, Unset, str]
        if isinstance(self.perceval_circuit, Unset):
            perceval_circuit = UNSET
        else:
            perceval_circuit = self.perceval_circuit

        qiskit_circuit: Union[None, Unset, str]
        if isinstance(self.qiskit_circuit, Unset):
            qiskit_circuit = UNSET
        else:
            qiskit_circuit = self.qiskit_circuit

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if perceval_circuit is not UNSET:
            field_dict["perceval_circuit"] = perceval_circuit
        if qiskit_circuit is not UNSET:
            field_dict["qiskit_circuit"] = qiskit_circuit

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)

        def _parse_perceval_circuit(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        perceval_circuit = _parse_perceval_circuit(d.pop("perceval_circuit", UNSET))

        def _parse_qiskit_circuit(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        qiskit_circuit = _parse_qiskit_circuit(d.pop("qiskit_circuit", UNSET))

        scaleway_qaas_v1_alpha_1_job_circuit = cls(
            perceval_circuit=perceval_circuit,
            qiskit_circuit=qiskit_circuit,
        )

        scaleway_qaas_v1_alpha_1_job_circuit.additional_properties = d
        return scaleway_qaas_v1_alpha_1_job_circuit

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
